@@ -18,7 +18,7 @@
 //
 // to contact the author : dar.linux@free.fr
 /*********************************************************************/
-// $Id: config_file.cpp,v 1.6.4.1 2003/12/20 23:05:34 edrusb Rel $
+// $Id: config_file.cpp,v 1.6.4.2 2004/05/07 12:41:24 edrusb Rel $
 //
 /*********************************************************************/
 //
@@ -100,7 +100,7 @@ bool config_file::find_next_target(generic_file &f, infinint & debut, string & n
     debut = f.get_position();
 
 
-    while(f.read(&a, 1) == 1 && !found)
+    while(!found && f.read(&a, 1) == 1)
     {
         switch(status)
         {
@@ -170,6 +170,6 @@ bool config_file::find_next_target(generic_file &f, infinint & debut, string & n
 
 static void dummy_call(char *x)
 {
-    static char id[]="$Id: config_file.cpp,v 1.6.4.1 2003/12/20 23:05:34 edrusb Rel $";
+    static char id[]="$Id: config_file.cpp,v 1.6.4.2 2004/05/07 12:41:24 edrusb Rel $";
     dummy_call(id);
 }
