@@ -18,12 +18,10 @@
 //
 // to contact the author : dar.linux@free.fr
 /*********************************************************************/
-// $Id: catalogue.cpp,v 1.18.2.1 2003/12/20 23:05:34 edrusb Rel $
+// $Id: catalogue.cpp,v 1.18.2.4 2004/09/10 20:15:27 edrusb Exp $
 //
 /*********************************************************************/
 
-#pragma implementation
-
 #include "../my_config.h"
 
 extern "C"
@@ -557,7 +555,7 @@ namespace libdar
             || (!ignore_owner && gid != ref.gid)
             || perm != ref.perm;
 
-        if(ref.last_mod < last_mod)
+        if(*ref.last_mod < *last_mod)
             if(hourshift > 0)
                 more_recent = more_recent || ! is_equal_with_hourshift(hourshift, *ref.last_mod, *last_mod);
             else
@@ -1111,6 +1109,16 @@ namespace libdar
         x_ref = ref;
     }
 
+    infinint hard_link::get_etiquette() const
+    {
+	if(x_ref == NULL)
+	    throw SRC_BUG;
+	if(dynamic_cast<file_etiquette *>(x_ref) == NULL)
+	    throw SRC_BUG;
+
+	return x_ref->get_etiquette();
+    }
+
     lien::lien(U_16 uid, U_16 gid, U_16 perm,
                const infinint & last_access,
                const infinint & last_modif,
@@ -2028,7 +2036,7 @@ namespace libdar
 
     static void dummy_call(char *x)
     {
-        static char id[]="$Id: catalogue.cpp,v 1.18.2.1 2003/12/20 23:05:34 edrusb Rel $";
+        static char id[]="$Id: catalogue.cpp,v 1.18.2.4 2004/09/10 20:15:27 edrusb Exp $";
         dummy_call(id);
     }
 
