@@ -18,7 +18,7 @@
 //
 // to contact the author : dar.linux@free.fr
 /*********************************************************************/
-// $Id: filesystem.cpp,v 1.17.2.3 2004/02/01 21:21:21 edrusb Rel $
+// $Id: filesystem.cpp,v 1.17.2.7 2004/09/12 21:43:44 edrusb Exp $
 //
 /*********************************************************************/
 
@@ -202,6 +202,13 @@ namespace libdar
                         }
                         else  // inode already seen previously
                         {
+				// some sanity checks
+			    if(it->second.obj == NULL)
+				throw SRC_BUG;
+			    if(dynamic_cast<file_etiquette *>(it->second.obj) == NULL)
+				throw SRC_BUG;
+				////
+
                             ref = new hard_link(name, it->second.obj);
 
                             if(ref != NULL)
@@ -308,14 +315,14 @@ namespace libdar
 ///////////////////////////////////////////////////////////////////
 
 
-    filesystem_backup::filesystem_backup(const path &root, bool x_info_details, bool root_ea, bool user_ea, bool check_no_dump_flag)
+    filesystem_backup::filesystem_backup(const path &root, bool x_info_details, bool x_save_root_ea, bool x_save_user_ea, bool check_no_dump_flag)
     {
 	fs_root = get_root_with_symlink(root, x_info_details);
 	if(fs_root == NULL)
 	    throw Ememory("filesystem_backup::filesystem_backup");
 	info_details = x_info_details;
-	ea_root = root_ea;
-	ea_user = user_ea;
+	save_root_ea = x_save_root_ea;
+	save_user_ea = x_save_user_ea;
 	no_dump_check = check_no_dump_flag;
 	current_dir = NULL;
         reset_read();
@@ -329,7 +336,10 @@ namespace libdar
             fs_root = NULL;
         }
         if(current_dir != NULL)
+	{
             delete current_dir;
+	    current_dir = NULL;
+	}
     }
 
     void filesystem_backup::copy_from(const filesystem_backup & ref)
@@ -344,10 +354,9 @@ namespace libdar
         else
             current_dir = NULL;
         info_details = ref.info_details;
-        ea_root = ref.ea_root;
-        ea_user = ref.ea_user;
+        save_root_ea = ref.save_root_ea;
+        save_user_ea = ref.save_user_ea;
         no_dump_check = ref.no_dump_check;
-        filename_pile = ref.filename_pile;
         pile = ref.pile;
     }
 
@@ -360,7 +369,6 @@ namespace libdar
         if(current_dir != NULL)
             delete current_dir;
         current_dir = new path(*fs_root);
-        filename_pile.clear();
         if(current_dir == NULL)
             throw Ememory("filesystem_backup::reset_read");
         pile.clear();
@@ -368,19 +376,12 @@ namespace libdar
         tmp = tools_str2charptr(current_dir->display());
         try
         {
-            entree *ref = make_read_entree(*current_dir, "", true, ea_root, ea_user);
+            entree *ref = make_read_entree(*current_dir, "", true, save_root_ea, save_user_ea);
             directory *ref_dir = dynamic_cast<directory *>(ref);
             try
             {
-                pile.push_back(etage(tmp));
                 if(ref_dir != NULL)
-                {
-                    filename_struct rfst;
-
-                    rfst.last_acc = pile.back().last_acc = ref_dir->get_last_access();
-                    rfst.last_mod = pile.back().last_mod = ref_dir->get_last_modif();
-                    filename_pile.push_back(rfst);
-                }
+		    pile.push_back(etage(tmp, ref_dir->get_last_access(), ref_dir->get_last_modif()));
                 else
                     if(ref == NULL)
                         throw Erange("filesystem_backup::reset_read", string("Non existant file: ") + tmp);
@@ -447,58 +448,66 @@ namespace libdar
 
                         if(!no_dump_check || !is_nodump_flag_set(*current_dir, name))
                         {
-                            ref = make_read_entree(*current_dir, name, true, ea_root, ea_user);
-                            directory *ref_dir = dynamic_cast<directory *>(ref);
+                            ref = make_read_entree(*current_dir, name, true, save_root_ea, save_user_ea);
 
-                            if(ref_dir != NULL)
-                            {
-                                char *ptr_name;
+			    try
+			    {
+				directory *ref_dir = dynamic_cast<directory *>(ref);
 
-                                *current_dir += name;
-                                ptr_name = tools_str2charptr(current_dir->display());
+				if(ref_dir != NULL)
+				{
+				    char *ptr_name;
 
-                                try
-                                {
-                                    pile.push_back(etage(ptr_name));
-                                    pile.back().last_acc = ref_dir->get_last_access();
-                                    pile.back().last_mod = ref_dir->get_last_modif();
-                                }
-                                catch(Erange & e)
-                                {
-                                    string tmp;
+				    *current_dir += name;
+				    ptr_name = tools_str2charptr(current_dir->display());
 
-                                    user_interaction_warning(string("error openning ") + ptr_name + " : " + e.get_message());
-                                    try
-                                    {
-                                        pile.push_back(etage());
-                                        pile.back().last_acc = 0;
-                                        pile.back().last_mod = 0;
-                                    }
-                                    catch(Erange & e)
-                                    {
-                                        delete ref;
-                                        once_again = true;
-                                        ref = NULL;
-                                        if(! current_dir->pop(tmp))
-                                            throw SRC_BUG;
-                                    }
-                                }
-                                catch(Egeneric & e)
-                                {
-                                    delete ptr_name;
-                                    delete ref;
-                                    throw;
-                                }
+				    try
+				    {
+					try
+					{
+					    pile.push_back(etage(ptr_name, ref_dir->get_last_access(), ref_dir->get_last_modif()));
+					}
+					catch(Egeneric & e)
+					{
+					    string tmp;
 
-                                delete ptr_name;
-                            }
+					    user_interaction_warning(string("Cannot read directory contents: ") + ptr_name + " : " + e.get_message());
+					    try
+					    {
+						pile.push_back(etage());
+					    }
+					    catch(Egeneric & e)
+					    {
+						delete ref;
+						ref = NULL; // we ignore this directory and skip to the next one
+						if(! current_dir->pop(tmp))
+						    throw SRC_BUG;
+					    }
+					}
+				    }
+				    catch(...)
+				    {
+					delete ptr_name;
+					throw;
+				    }
+				    delete ptr_name;
+				}
 
-
-                            if(ref == NULL)
-                                once_again = true;
-                                // the file has been removed between the time
-                                // the directory has been openned, and the time
-                                // we try to read it, so we ignore it.
+				if(ref == NULL)
+				    once_again = true;
+				    // the file has been removed between the time
+				    // the directory has been openned, and the time
+				    // we try to read it, so we ignore it.
+			    }
+			    catch(...)
+			    {
+				if(ref != NULL)
+				{
+				    delete ref;
+				    ref = NULL;
+				}
+				throw;
+			    }
                         }
                         else // EXT2 nodump flag is set, and we must not consider such file for backup
                         {
@@ -545,14 +554,14 @@ namespace libdar
 ///////////////////////////////////////////////////////////////////
 
 
-    filesystem_diff::filesystem_diff(const path &root, bool x_info_details, bool root_ea, bool user_ea)
+    filesystem_diff::filesystem_diff(const path &root, bool x_info_details, bool x_check_root_ea, bool x_check_user_ea)
     {
 	fs_root = get_root_with_symlink(root, x_info_details);
 	if(fs_root == NULL)
 	    throw Ememory("filesystem_diff::filesystem_diff");
 	info_details = x_info_details;
-	ea_root = root_ea;
-	ea_user = user_ea;
+	check_root_ea = x_check_root_ea;
+	check_user_ea = x_check_user_ea;
 	current_dir = NULL;
 
         reset_read();
@@ -574,7 +583,7 @@ namespace libdar
         tmp = tools_str2charptr(current_dir->display());
         try
         {
-            entree *ref = make_read_entree(*current_dir, "", true, ea_root, ea_user);
+            entree *ref = make_read_entree(*current_dir, "", true, check_root_ea, check_user_ea);
             directory *ref_dir = dynamic_cast<directory *>(ref);
             try
             {
@@ -590,7 +599,7 @@ namespace libdar
                     if(ref == NULL)
                         throw Erange("filesystem_diff::reset_read", string("Non existant file: ") + tmp);
                     else
-                        throw Erange("filesystem_diff::reset_read", string("File must be a directory: ")+ tmp);
+                        throw Erange("filesystem_diff::reset_read", string("File must be a directory: ") + tmp);
             }
             catch(...)
             {
@@ -614,7 +623,7 @@ namespace libdar
         directory *ref_dir = NULL;
         if(current_dir == NULL)
             throw SRC_BUG;
-        ref = make_read_entree(*current_dir, name, false, ea_root, ea_user);
+        ref = make_read_entree(*current_dir, name, false, check_root_ea, check_user_ea);
         if(ref == NULL)
             return false; // no file of that name
         else
@@ -665,8 +674,8 @@ namespace libdar
         else
             current_dir = NULL;
         info_details = ref.info_details;
-        ea_root = ref.ea_root;
-        ea_user = ref.ea_user;
+        check_root_ea = ref.check_root_ea;
+        check_user_ea = ref.check_user_ea;
         filename_pile = ref.filename_pile;
     }
 
@@ -689,6 +698,7 @@ namespace libdar
 
     bool filesystem_hard_link_write::set_ea(const nomme *e, const ea_attributs & l, path spot,
                                             bool allow_overwrite, bool warn_overwrite,
+					    bool set_root_ea, bool set_user_ea,
                                             bool info_details)
     {
         const etiquette *e_eti = dynamic_cast<const etiquette *>(e);
@@ -731,14 +741,14 @@ namespace libdar
 
                 // restoring the root EA
                 //
-            exists = ea_filesystem_is_present(chemin, ea_root);
+            exists = ea_filesystem_is_present(chemin, ea_domain_root);
             if(!exists || allow_overwrite)
             {
-                if(ea_root)
+                if(set_root_ea)
                 {
                     if(exists && warn_overwrite)
                         user_interaction_pause(string("system EA for ")+chemin+ " are about to be overwriten, continue ? ");
-                    ea_filesystem_clear_ea(chemin, ea_root);
+                    ea_filesystem_clear_ea(chemin, ea_domain_root);
                     if(ea_filesystem_write_ea(chemin, l, true, false))
                     {
                         if(info_details)
@@ -751,19 +761,19 @@ namespace libdar
                 }
             }
             else
-                if(ea_root)
+                if(set_root_ea)
                     user_interaction_warning(string("system EA for ")+chemin+" will not be restored, (overwriting not allowed)");
 
                 // restoring the user EA
                 //
-            exists = ea_filesystem_is_present(chemin, ea_user);
+            exists = ea_filesystem_is_present(chemin, ea_domain_user);
             if(!exists || allow_overwrite)
             {
-                if(ea_user)
+                if(set_user_ea)
                 {
                     if(exists && warn_overwrite)
                         user_interaction_pause(string("user EA for ")+chemin+ " are about to be overwriten, continue ? ");
-                    ea_filesystem_clear_ea(chemin, ea_user);
+                    ea_filesystem_clear_ea(chemin, ea_domain_user);
                     if(ea_filesystem_write_ea(chemin, l, false, true))
                     {
                         if(info_details)
@@ -776,7 +786,7 @@ namespace libdar
                 }
             }
             else
-                if(ea_user)
+                if(set_user_ea)
                     user_interaction_warning(string("user EA for ")+chemin+" will not be restored, (overwriting not allowed)");
         }
         catch(Euser_abort & e)
@@ -910,7 +920,7 @@ namespace libdar
                     generic_file *ou;
                     infinint seek;
 
-                    ret = open(name, O_WRONLY|O_CREAT|O_BINARY, 0777);
+                    ret = ::open(name, O_WRONLY|O_CREAT|O_BINARY, 0777);
                     if(ret >= 0)
                     {
                         fichier dest = ret;
@@ -1007,7 +1017,7 @@ namespace libdar
 
     filesystem_restore::filesystem_restore(const path &root, bool x_allow_overwrite,
                                            bool x_warn_overwrite, bool x_info_details,
-                                           bool root_ea, bool user_ea, bool ignore_owner,
+                                           bool x_set_root_ea, bool x_set_user_ea, bool ignore_owner,
 					   bool x_warn_remove_no_match, bool x_empty)
     {
 	fs_root = get_root_with_symlink(root, x_info_details);
@@ -1016,8 +1026,8 @@ namespace libdar
 	allow_overwrite = x_allow_overwrite;
 	warn_overwrite = x_warn_overwrite;
 	info_details = x_info_details;
-	ea_root = root_ea;
-	ea_user = user_ea;
+	set_root_ea = x_set_root_ea;
+	set_user_ea = x_set_user_ea;
 	ignore_ownership = ignore_owner;
 	warn_remove_no_match = x_warn_remove_no_match;
 	current_dir = NULL;
@@ -1070,7 +1080,7 @@ namespace libdar
                     const inode *x_ino = dynamic_cast<const inode *>(x);
                     const etiquette *x_eti = dynamic_cast<const etiquette *>(x);
 
-                    nomme *exists = make_read_entree(*current_dir, x_nom->get_name(), false, ea_root, ea_user);
+                    nomme *exists = make_read_entree(*current_dir, x_nom->get_name(), false, set_root_ea, set_user_ea);
 
                     try
                     {
@@ -1198,7 +1208,7 @@ namespace libdar
 
     nomme *filesystem_restore::get_before_write(const nomme *x)
     {
-        return make_read_entree(*current_dir, x->get_name(), false, ea_root, ea_user);
+        return make_read_entree(*current_dir, x->get_name(), false, set_root_ea, set_user_ea);
     }
 
     void filesystem_restore::pseudo_write(const directory *dir)
@@ -1207,7 +1217,7 @@ namespace libdar
             throw SRC_BUG;
 
         path spot = *current_dir + dir->get_name();
-        nomme *exists = make_read_entree(*current_dir, dir->get_name(), false, ea_root, ea_user);
+        nomme *exists = make_read_entree(*current_dir, dir->get_name(), false, set_root_ea, set_user_ea);
 
         try
         {
@@ -1287,8 +1297,8 @@ namespace libdar
         else
             current_dir = NULL;
         info_details = ref.info_details;
-        ea_root = ref.ea_root;
-        ea_user = ref.ea_user;
+        set_root_ea = ref.set_root_ea;
+        set_user_ea = ref.set_user_ea;
         allow_overwrite = ref.allow_overwrite;
         warn_overwrite = ref.warn_overwrite;
         ignore_ownership = ref.ignore_ownership;
@@ -1315,12 +1325,14 @@ namespace libdar
 
             if(S_ISDIR(buf.st_mode))
             {
-                etage fils = s;
+                etage fils = etage(s,0,0); // we don't care the access and modification time because directory will be destroyed
                 string tmp;
 
+		    // first we destroy directory's children
                 while(fils.read(tmp))
                     supprime(ref+tmp);
 
+		    // then the directory itself
                 if(rmdir(s) < 0)
                     throw Erange("supprime (dir)", string("Cannot remove directory ") + s + " : " + strerror(errno));
             }
@@ -1339,7 +1351,7 @@ namespace libdar
 
     static void dummy_call(char *x)
     {
-        static char id[]="$Id: filesystem.cpp,v 1.17.2.3 2004/02/01 21:21:21 edrusb Rel $";
+        static char id[]="$Id: filesystem.cpp,v 1.17.2.7 2004/09/12 21:43:44 edrusb Exp $";
         dummy_call(id);
     }
 
@@ -1457,8 +1469,8 @@ namespace libdar
     {
         try
         {
-            if(last_acc != 0 || last_mod != 0)
-                make_date(chem, last_acc, last_mod);
+	    if(last_acc != 0 || last_mod != 0)
+		make_date(chem, last_acc, last_mod);
                 // else the directory could not be openned properly
                 // and time could not be retrieved, so we don't try
                 // to restore them
@@ -1477,7 +1489,7 @@ namespace libdar
 
         try
         {
-            fd = open(ptr, O_RDONLY|O_BINARY|O_NONBLOCK);
+            fd = ::open(ptr, O_RDONLY|O_BINARY|O_NONBLOCK);
             if(fd < 0)
 		user_interaction_warning(string("Failed to open ") + filename +" while checking for nodump flag: " + strerror(errno));
 	    else
